{
  description = "Your new nix config";

  inputs = {
    # Nixpkgs (usually unstable)
    nixpkgs.url = "github:nixos/nixpkgs/nixos-unstable";
    nixpkgs-stable.url = "github:nixos/nixpkgs/nixos-23.11";
    nixpkgs-unstable.url = "github:nixos/nixpkgs/nixos-unstable";

    # Home manageKr
    home-manager = {
      url = "github:nix-community/home-manager";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    
    # Darwin & Apple Silicon tools
    darwin = {
      url = "github:lnl7/nix-darwin";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    apple-silicon.url = "github:tpwrules/nixos-apple-silicon";

    # KDE Plasma 6+
    #kde2nix.url = "github:nix-community/kde2nix";
    
    # Secrets	
    sops-nix.url = "github:Mic92/sops-nix";
    #sops-nix-darwin.url = "github:Kloenk/sops-nix?ref=darwin";
    
    # Fancy stuff
    #nix-colors.url = "github:misterio77/nix-colors";
    nixvim = {
      url = "github:nix-community/nixvim?rev=1d8e7906c9606c956c6b40d8d088c8d2110dc0c0";
      inputs.nixpkgs.follows = "nixpkgs-unstable";
    };
    #nur.url = "github:nix-community/nur";
    #firefox-addons.url = "gitlab:rycee/nur-expressions?dir=pkgs/firefox-addons";

    # Pro gamer move
    nixos-generators.url = "github:nix-community/nixos-generators";

    # Server tools
    conduit = {
      url = "gitlab:famedly/conduit";
      inputs.nixpkgs.follows = "nixpkgs";
    };
  };

  nixConfig = {
    #extra-substituters = [
    #  "https://nix-community.cachix.org"
    #  "https://0uptime.cachix.org"
    #];

    #extra-trusted-public-keys = [
    #  "nix-community.cachix.org-1:mB9FSh9qf2dCimDSUo8Zy7bkq5CX+/rkCWyvRCYg3Fs="
    #  "0uptime.cachix.org-1:ctw8yknBLg9cZBdqss+5krAem0sHYdISkw/IFdRbYdE="
    #];
  };

  outputs = { self, nixpkgs, home-manager, ... }@inputs:
    let
      inherit (self) outputs;
      forAllSystems = nixpkgs.lib.genAttrs [
        "aarch64-linux"
        "i686-linux"
        "x86_64-linux"
        "aarch64-darwin"
        "x86_64-darwin"
      ];

      mkNixos = modules: nixpkgs.lib.nixosSystem {
        inherit modules;
        specialArgs = { inherit inputs outputs; };
      };

      mkDarwin = system: modules: inputs.darwin.lib.darwinSystem {
        inherit modules system inputs;
        specialArgs = { inherit inputs outputs; };
      };

      mkHome = modules: pkgs: home-manager.lib.homeManagerConfiguration {
        inherit modules pkgs;
        extraSpecialArgs = { inherit inputs outputs; };
      };
    in {
      # Your custom packages
      # Acessible through 'nix build', 'nix shell', etc
      packages = forAllSystems (system:
        let pkgs = nixpkgs.legacyPackages.${system};
        in import ./pkgs { inherit pkgs; } // 
        {
          proxmox-lxc = inputs.nixos-generators.nixosGenerate {
            inherit system pkgs;
            modules = [
              ./nixos/templates/proxmox-lxc.nix
            ];
            format = "proxmox-lxc";
          };
        }
      );
      
      # Devshell for bootstrapping
      # Acessible through 'nix develop' or 'nix-shell' (legacy)
      devShells = forAllSystems (system:
        let pkgs = nixpkgs.legacyPackages.${system};
        in import ./shell.nix { inherit pkgs; }
      );

      # Your custom packages and modifications, exported as overlays
      overlays = import ./overlays { inherit inputs; };
      
      # Reusable nixos modules you might want to export
      # These are usually stuff you would upstream into nixpkgs
      nixosModules = import ./modules/nixos;

      # Reusable home-manager modules you might want to export
      # These are usually stuff you would upstream into home-manager
      homeManagerModules = import ./modules/home-manager;

      # Reusable nix-darwin packages you might want to export
      # These are usually hacks!
      darwinModules = import ./modules/darwin;

      # NixOS configuration entrypoint
      # Available through 'nixos-rebuild --flake .#your-hostname'
      nixosConfigurations = {
        aerial = mkNixos [ ./nixos/hosts/aerial ]; # desktop
        cider = mkNixos [ ./nixos/hosts/cider ]; # asahi m2 mba
	      drone = mkNixos [ ./nixos/hosts/drone ]; # spectre x360
        happystaticbuzz = mkNixos [ ./nixos/hosts/happystaticbuzz ]; # GoToSocial (happ.ystatic.buzz)
        ingress-proxy = mkNixos [ ./nixos/hosts/ingress-proxy ]; # nginx edge proxy
        keylime = mkNixos [ ./nixos/hosts/keylime ]; # lab jump
        keysmash = mkNixos [ ./nixos/hosts/keysmash ]; # GoToSocial (keysmash IDN lol)
        lab-alpha = mkNixos [ ./nixos/hosts/lab-alpha ]; # what the mia doin
        mango = mkNixos [ ./nixos/hosts/mango ]; # Matrix (mx.sapphic.engineer)
        thonkpad = mkNixos [ ./nixos/hosts/thonkpad ]; # t480
      };

      darwinConfigurations = {
        # in asahi => noe-air = mkDarwin "aarch64-darwin" [ ./darwin/hosts/noe-air ];
        AMERMACC02G65A8MD6T = mkDarwin "x86_64-darwin" [ ./darwin/hosts/work-mac ];
      };

      # Standalone home-manager configuration entrypoint
      # Available through 'home-manager --flake .#your-username@your-hostname'
      homeConfigurations = {
        # TODO: add generic standalone home-manager config
      };
    };
}

